@@ -1,20 +1,20 @@
 /*
  *  Copyright 2010 Ruediger Gad
  *
- *  This file is part of Binary Clock.
+ *  This file is part of Advanced Clock Plugin.
  *
- *  Binary Clock is free software: you can redistribute it and/or modify
+ *  Advanced Clock Plugin is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  Binary Clock is distributed in the hope that it will be useful,
+ *  Advanced Clock Plugin is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Advanced Clock Plugin.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef Q_WS_MAEMO_5
@@ -28,18 +28,21 @@
 #include <QDir>
 #include <QFile>
 #include <QFileDialog>
+#include <QList>
 #include <QString>
 
+#include "clockdesktopconfigbutton.h"
 #include "dialog.h"
 #include "ui_dialog.h"
 
 const QString Dialog::GCONF_PATH = "/apps/Maemo/advanced_clock_plugin";
 const QString Dialog::GCONF_PATH_CLOCK = Dialog::GCONF_PATH + "/clock";
 
-Dialog::Dialog(QWidget *parent) :
+Dialog::Dialog(int viewId, QWidget *parent) :
     QDialog(parent),
     ui(new Ui::Dialog)
 {
+    this->viewId = viewId;
     ui->setupUi(this);
 
     /*
@@ -86,29 +89,51 @@ Dialog::Dialog(QWidget *parent) :
     connect(ui->colorRSpinBox, SIGNAL(valueChanged(int)), ui->colorChooserButton, SLOT(updateR(int)));
     connect(ui->colorGSpinBox, SIGNAL(valueChanged(int)), ui->colorChooserButton, SLOT(updateG(int)));
     connect(ui->colorBSpinBox, SIGNAL(valueChanged(int)), ui->colorChooserButton, SLOT(updateB(int)));
-    connect(ui->alarmIndicatorIconPushButton, SIGNAL(pressed()), this, SLOT(fileDialog()));
+    connect(ui->alarmIndicatorIconPushButton, SIGNAL(clicked()), this, SLOT(fileDialog()));
 
 #ifdef Q_WS_MAEMO_5
+    if(this->viewId < 0){
+        gconfClockName = GCONF_PATH + "/clock_name";
+        gconfClockPath = Dialog::GCONF_PATH + "/clock";
+
+        clockPerDesktop = new GConfItem(GCONF_PATH + "/clock_per_desktop");
+        ui->clockPerDesktopCheckBox->setChecked(clockPerDesktop->value().toBool());
+
+        GConfItem activeViews("/apps/osso/hildon-desktop/views/active");
+        QList<QVariant> viewIds = activeViews.value().toList();
+
+        for(int i = 0; i < viewIds.length(); i++){
+            ClockDesktopConfigButton *button = new ClockDesktopConfigButton(viewIds.at(i).toInt());
+            button->setText("Desktop " + viewIds.at(i).toString());
+            ui->clockPerDesktopLayout->addWidget(button);
+        }
+    }else{
+        gconfClockName = GCONF_PATH + "/clock_name_" + QString::number(viewId);
+        gconfClockPath = Dialog::GCONF_PATH + "/clock_" + QString::number(viewId);
+
+        ui->clockPerDesktopCheckBox->close();
+    }
+
     /*
      * Initialize GConfItems.
      */
-    clockName = new GConfItem(GCONF_PATH + "/clock_name");
-    showSeconds = new GConfItem(GCONF_PATH_CLOCK + "/show_seconds");
-    twelveHourMode = new GConfItem(GCONF_PATH_CLOCK + "/twelve_hour_mode");
-    fill = new GConfItem(GCONF_PATH_CLOCK + "/fill");
-    showAlarmIndicator = new GConfItem(GCONF_PATH_CLOCK + "/alarm_indicator_enabled");
-    colorR = new GConfItem(GCONF_PATH_CLOCK + "/color_r");
-    colorG = new GConfItem(GCONF_PATH_CLOCK + "/color_g");
-    colorB = new GConfItem(GCONF_PATH_CLOCK + "/color_b");
-    fontName = new GConfItem(GCONF_PATH_CLOCK + "/font_name");
-    textScaling = new GConfItem(GCONF_PATH_CLOCK + "/text_scaling");
-    padZeros = new GConfItem(GCONF_PATH_CLOCK + "/pad_zeros");
-    city = new GConfItem(GCONF_PATH_CLOCK + "/city");
-    country = new GConfItem(GCONF_PATH_CLOCK + "/country");
-    offset = new GConfItem(GCONF_PATH_CLOCK + "/offset");
-    timeZone = new GConfItem(GCONF_PATH_CLOCK + "/time_zone");
-    customFormat = new GConfItem(GCONF_PATH_CLOCK + "/custom_format");
-    alarmIndicatorIcon = new GConfItem(GCONF_PATH_CLOCK + "/alarm_indicator_icon");
+    clockName = new GConfItem(gconfClockName);
+    showSeconds = new GConfItem(gconfClockPath + "/show_seconds");
+    twelveHourMode = new GConfItem(gconfClockPath + "/twelve_hour_mode");
+    fill = new GConfItem(gconfClockPath + "/fill");
+    showAlarmIndicator = new GConfItem(gconfClockPath + "/alarm_indicator_enabled");
+    colorR = new GConfItem(gconfClockPath + "/color_r");
+    colorG = new GConfItem(gconfClockPath + "/color_g");
+    colorB = new GConfItem(gconfClockPath + "/color_b");
+    fontName = new GConfItem(gconfClockPath + "/font_name");
+    textScaling = new GConfItem(gconfClockPath + "/text_scaling");
+    padZeros = new GConfItem(gconfClockPath + "/pad_zeros");
+    city = new GConfItem(gconfClockPath + "/city");
+    country = new GConfItem(gconfClockPath + "/country");
+    offset = new GConfItem(gconfClockPath + "/offset");
+    timeZone = new GConfItem(gconfClockPath + "/time_zone");
+    customFormat = new GConfItem(gconfClockPath + "/custom_format");
+    alarmIndicatorIcon = new GConfItem(gconfClockPath + "/alarm_indicator_icon");
 
     /*
      * Initialize UI with the values stored in gconf.
@@ -184,6 +209,10 @@ Dialog::~Dialog()
     delete offset;
     delete timeZone;
     delete customFormat;
+
+    if (this->viewId < 0){
+        delete clockPerDesktop;
+    }
 #endif
 }
 
@@ -224,6 +253,10 @@ void Dialog::accept(){
         alarmIndicatorIcon->set("");
     }
 
+    if (this->viewId < 0){
+        clockPerDesktop->set(ui->clockPerDesktopCheckBox->isChecked());
+    }
+
     /*
      * Hack to get things updated even when the clock is not changed.
      * This is currently needed as the settings are currently updated
@@ -234,7 +267,7 @@ void Dialog::accept(){
     clockName->set(ui->clockStyleComboBox->currentText());
 #endif
 
-    done(1);
+    done(QDialog::Accepted);
 }
 
 void Dialog::fileDialog(){
