@@ -1,20 +1,20 @@
 /*
  *  Copyright 2010 Ruediger Gad
  *
- *  This file is part of Binary Clock.
+ *  This file is part of Advanced Clock Plugin.
  *
- *  Binary Clock is free software: you can redistribute it and/or modify
+ *  Advanced Clock Plugin is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  Binary Clock is distributed in the hope that it will be useful,
+ *  Advanced Clock Plugin is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Advanced Clock Plugin.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DIALOG_H
@@ -39,7 +39,7 @@ class Dialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit Dialog(QWidget *parent = 0);
+    explicit Dialog(int viewId = -1, QWidget *parent = 0);
     ~Dialog();
 
     void accept();
@@ -55,6 +55,10 @@ private:
     void fileSelected(QString fileName);
 
 #ifdef Q_WS_MAEMO_5
+    int viewId;
+    QString gconfClockName;
+    QString gconfClockPath;
+
     GConfItem *clockName;
     GConfItem *showSeconds;
     GConfItem *twelveHourMode;
@@ -75,6 +79,8 @@ private:
     GConfItem *customFormat;
     GConfItem *alarmIndicatorIcon;
 
+    GConfItem *clockPerDesktop;
+
     QStringList cityNames;
     QStringList countryNames;
     QStringList timeZones;
