@@ -26,9 +26,6 @@ def get_name():
     return "BCD Clock"
 
 class BcdClock(clock.Clock):
-    def __init__(self, drawing_area):
-        clock.Clock.__init__(self, drawing_area)
-
     def draw_bits_vertically(self, x, y, radius, value, n):
         for i in range(n):
             self.context.arc(x + radius, y + (1.5 * radius)  + (3 * radius * i), radius, 0, 2 * math.pi)
