@@ -26,9 +26,6 @@ def get_name():
     return "Display Localtime and Time from another Timezone"
 
 class TimeZoneClock(clock.Clock):
-    def __init__(self, drawing_area):
-        clock.Clock.__init__(self, drawing_area)
-
     def draw_clock(self):
 # Draw time.
         self.context.set_font_size(int(self.text_scaling * 20))
